pecos.tools.find\_cliffs
========================

.. automodule:: pecos.tools.find_cliffs

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      m2cliff
      mnormal
      r1xy2cliff
      r1xy_matrix
      rz2cliff
      rz_matrix
   
   

   
   
   

   
   
   



